Summary: The Visualization Toolkit - A high level 3D visualization library
Name: vtk
Version: 2.1
Release: 1
Copyright: Distributable
Group: X11/Libraries
Source: ftp://ftp.kitware.com/kitware/vtk21src.tar.gz
Patch: vtk-2.1-config.patch
Buildroot: /usr/local/tmp/vtk-root

%description 
VTK - the Visualization Toolkit is an object oriented, high level
library that allows one to easily write C++ programs and Tcl, Python,
Java scripts that do 3D visualization.  This package provides the
shared libraries needed to run C++, Python and Tcl programs and the
tcl interpreter for vtk.

VTK enables the user to concentrate on his/her work by providing
excellent and feature packed high level functions that do 3D
visualization.  The library needs OpenGL to render the graphics and
for Linux machines Mesa is necessary. The terms/copyright can be read
in /usr/doc/vtk*/README and README.html.  README.vtk has general
information about this rpm and how to use VTK.  The patented classes
(few in number) are not to be used commercially. Please read the
files README.patented-dir and README.patented-classes.

%package devel
Summary: VTK header files for building C++ code.
Requires: vtk
Group: Development/Libraries

%description devel 
This provides the VTK header files required to compile C++ programs
that use VTK to do 3D visualisation. For details on how to compile,
read the README.vtk in the /usr/doc/vtk* directory.

%package examples
Summary: C++, Tcl and Python example programs/scripts for VTK.
Requires: vtk
Group: Development/Libraries

%description examples
This package contains all the C++, Tcl and Python examples from the
VTK source.  To compile the C++ examples you will need to install the
vtk-devel package as well. The Python and Tcl examples can be run
without the vtk-devel package.

%prep

%setup -n vtk
%patch -p1
chown -R root.root *

%build

./configure --with-mesa --with-shared --with-tcl --with-python --with-contrib --with-patented --prefix=$RPM_BUILD_ROOT/usr

# In all the RH5.1 SRPMS i see that --prefix=/usr and only later while
# doing a make install do they actually set prefix=$RPM_BUILD_ROOT/usr
# dont know why but i will not do the same here.
 
make

%install

cp ./patented/README ./README.patented-dir
echo -e "A list of the patented classes.\n\n" > README.patented-classes
ls ./patented/*.h >> README.patented-classes

rm -rf $RPM_BUILD_ROOT

#creating all the directories
install -d $RPM_BUILD_ROOT/usr/bin
install -d $RPM_BUILD_ROOT/usr/lib/vtk/{contrib/examplesTcl,examplesTcl/frog}
install -d $RPM_BUILD_ROOT/usr/lib/vtk/graphics/examples{Cxx,Tcl/RenderMan/Shaders,Python}
install -d $RPM_BUILD_ROOT/usr/lib/vtk/imaging/examples{,Tcl}
install -d $RPM_BUILD_ROOT/usr/lib/vtk/patented/examplesTcl
install -d $RPM_BUILD_ROOT/usr/include/vtk


# this installs the libs and the vtk tcl interpretor

make install
#make prefix=$RPM_BUILD_ROOT/usr install

#stripping all the shared libraries and the vtk interpreter
strip $RPM_BUILD_ROOT/usr/bin/vtk
strip $RPM_BUILD_ROOT/usr/lib/libVTK*

# copying the static libs for the devel package
# there are none built! so packing the following lines
#install -g 0 -o 0 -m 644 ./common/libVTK*.a $RPM_BUILD_ROOT/usr/lib
#install -g 0 -o 0 -m 644 ./graphics/libVTK*.a $RPM_BUILD_ROOT/usr/lib
#install -g 0 -o 0 -m 644 ./imaging/libVTK*.a $RPM_BUILD_ROOT/usr/lib
#install -g 0 -o 0 -m 644 ./contrib/libVTK*.a $RPM_BUILD_ROOT/usr/lib
#install -g 0 -o 0 -m 644 ./patented/libVTK*.a $RPM_BUILD_ROOT/usr/lib


# this installs all the header files.
install -g 0 -o 0 -m 644 ./common/*.h $RPM_BUILD_ROOT/usr/include/vtk
install -g 0 -o 0 -m 644 ./contrib/*.h $RPM_BUILD_ROOT/usr/include/vtk
install -g 0 -o 0 -m 644 ./wrap/*.h $RPM_BUILD_ROOT/usr/include/vtk
install -g 0 -o 0 -m 644 ./graphics/*.h $RPM_BUILD_ROOT/usr/include/vtk
install -g 0 -o 0 -m 644 ./imaging/*.h $RPM_BUILD_ROOT/usr/include/vtk
install -g 0 -o 0 -m 644 ./patented/*.h $RPM_BUILD_ROOT/usr/include/vtk

#installing all the examples...

install -g 0 -o 0 -m 644 ./contrib/examplesTcl/*.tcl $RPM_BUILD_ROOT/usr/lib/vtk/contrib/examplesTcl/

install -g 0 -o 0 -m 644 ./examplesTcl/*.tcl $RPM_BUILD_ROOT/usr/lib/vtk/examplesTcl/

install -g 0 -o 0 -m 644 ./examplesTcl/frog/*.tcl $RPM_BUILD_ROOT/usr/lib/vtk/examplesTcl/frog

install -g 0 -o 0 -m 644 ./graphics/examplesCxx/*.cxx $RPM_BUILD_ROOT/usr/lib/vtk/graphics/examplesCxx/
install -g 0 -o 0 -m 644 ./graphics/examplesCxx/Makefile* $RPM_BUILD_ROOT/usr/lib/vtk/graphics/examplesCxx/
install -g 0 -o 0 -m 755 ./graphics/examplesPython/*.py $RPM_BUILD_ROOT/usr/lib/vtk/graphics/examplesPython/
install -g 0 -o 0 -m 644 ./graphics/examplesTcl/{*.tcl,*.ppm} $RPM_BUILD_ROOT/usr/lib/vtk/graphics/examplesTcl/
install -g 0 -o 0 -m 644 ./graphics/examplesTcl/RenderMan/{*.so,*.tcl} $RPM_BUILD_ROOT/usr/lib/vtk/graphics/examplesTcl/RenderMan/
install -g 0 -o 0 -m 644 ./graphics/examplesTcl/RenderMan/Shaders/*.sl $RPM_BUILD_ROOT/usr/lib/vtk/graphics/examplesTcl/RenderMan/Shaders

install -g 0 -o 0 -m 644 ./imaging/examples/*.tcl $RPM_BUILD_ROOT/usr/lib/vtk/imaging/examples/
install -g 0 -o 0 -m 644 ./imaging/examplesTcl/*.tcl $RPM_BUILD_ROOT/usr/lib/vtk/imaging/examplesTcl/

install -g 0 -o 0 -m 644 ./patented/examplesTcl/*.tcl $RPM_BUILD_ROOT/usr/lib/vtk/patented/examplesTcl/


%post
#if [ "`grep /usr/local/lib /etc/ld.so.conf`" = "" ] ; then
#	echo "/usr/local/lib" >> ld.so.conf 
#fi
ldconfig

%postun 
ldconfig


%files
/usr/bin/vtk
/usr/lib/libVTK*.so

%doc README.vtk README README.html README.patented-dir vtkLogo.jpg
%doc README.patented-classes

%files devel
/usr/include/vtk/
#/usr/lib/libVTK*.a

%files examples
/usr/lib/vtk/


%clean 
rm -rf $RPM_BUILD_ROOT

